@@ -2,12 +2,11 @@ from datetime import datetime
 
 import numpy as np
 import pandas as pd
-from pandas import DataFrame
-import pandas.util.testing as tm
+from pandas import DataFrame, testing as tm
 import pytest
 
+from pandas_datareader import data as web
 from pandas_datareader._utils import RemoteDataError
-import pandas_datareader.data as web
 
 pytestmark = pytest.mark.stable
 
@@ -52,7 +51,7 @@ class TestFred(object):
     def test_fred_part2(self):
         expected = [[576.7], [962.9], [684.7], [848.3], [933.3]]
         result = web.get_data_fred("A09024USA144NNBR", start="1915").iloc[:5]
-        tm.assert_numpy_array_equal(result.values, np.array(expected))
+        np.testing.assert_array_equal(result.values, np.array(expected))
 
     def test_invalid_series(self):
         name = "NOT A REAL SERIES"
@@ -72,7 +71,10 @@ class TestFred(object):
             index=[pd.Timestamp("2010-01-01 00:00:00")],
         )
         expected.index.rename("DATE", inplace=True)
-        tm.assert_frame_equal(received, expected, check_less_precise=True)
+        expected.index.freq = "MS"
+        np.testing.assert_allclose(received, expected)
+        tm.assert_index_equal(received.index, expected.index)
+        tm.assert_index_equal(received.columns, expected.columns)
 
     def test_fred_multi_bad_series(self):
         names = ["NOTAREALSERIES", "CPIAUCSL", "ALSO FAKE"]
